@@ -62,11 +62,10 @@ class Viper:
                     self.passed += 1
                 else:
                     print(message + Fore.RED + "Failed" + Style.RESET_ALL)
-                    print(f"   Desired Output: {test['desiredOutput']} | Test Ouput: \"{test['functionOutput']}\"")
-            end = time.perf_counter() - (total * 0.75)
+                    print(f"   Desired Output: {test['desiredOutput']} | Test Ouput: {test['functionOutput']}")
+            end = time.perf_counter()
             time.sleep(0.75)
-            print("\n====================================== Test Summary ======================================")
-            print(f"Ran {total} test(s) in {end - start:0.4f} seconds")
+            print(f"\nRan {total} test(s) in {end - start:0.4f} seconds")
             print(f"{self.passed}/{total} passed")
         except KeyboardInterrupt:
             pass
\ No newline at end of file
